@@ -1,5 +1,5 @@
 /* Generic BFD support for file formats.
-   Copyright 1990, 1991, 1992, 1993, 1994, 1995, 1999, 2000, 2001
+   Copyright 1990, 1991, 1992, 1993, 1994, 1995, 1999, 2000, 2001, 2002
    Free Software Foundation, Inc.
    Written by Cygnus Support.
 
@@ -119,8 +119,9 @@ bfd_check_format_matches (abfd, format, matching)
      char ***matching;
 {
   extern const bfd_target binary_vec;
-  const bfd_target * const *target, *save_targ, *right_targ, *ar_right_targ;
-  char **matching_vector = NULL;
+  const bfd_target * const *target;
+  const bfd_target **matching_vector = NULL;
+  const bfd_target *save_targ, *right_targ, *ar_right_targ;
   int match_count;
   int ar_match_index;
 
@@ -132,7 +133,7 @@ bfd_check_format_matches (abfd, format, matching)
     }
 
   if (abfd->format != bfd_unknown)
-    return abfd->format == format;
+    return (boolean) (abfd->format == format);
 
   /* Since the target type was defaulted, check them
      all in the hope that one will be uniquely recognized.  */
@@ -142,10 +143,11 @@ bfd_check_format_matches (abfd, format, matching)
 
   if (matching)
     {
+      bfd_size_type amt;
+
       *matching = NULL;
-      matching_vector =
-	(char **) bfd_malloc (sizeof (char *)
-			      * 2 * _bfd_target_vector_entries);
+      amt = sizeof (*matching_vector) * 2 * _bfd_target_vector_entries;
+      matching_vector = (const bfd_target **) bfd_malloc (amt);
       if (!matching_vector)
 	return false;
     }
@@ -159,7 +161,7 @@ bfd_check_format_matches (abfd, format, matching)
   /* If the target type was explicitly specified, just check that target.  */
   if (!abfd->target_defaulted)
     {
-      if (bfd_seek (abfd, (file_ptr)0, SEEK_SET) != 0)	/* rewind! */
+      if (bfd_seek (abfd, (file_ptr) 0, SEEK_SET) != 0)	/* rewind! */
 	return false;
 
       right_targ = BFD_SEND_FMT (abfd, _bfd_check_format, (abfd));
@@ -169,7 +171,7 @@ bfd_check_format_matches (abfd, format, matching)
 	  abfd->xvec = right_targ;	/* Set the target as returned.  */
 
 	  if (matching)
-	    free (matching_vector);
+	    free ((PTR) matching_vector);
 
 	  return true;			/* File position has moved, BTW.  */
 	}
@@ -192,7 +194,7 @@ bfd_check_format_matches (abfd, format, matching)
 	  abfd->format = bfd_unknown;
 
 	  if (matching)
-	    free (matching_vector);
+	    free ((PTR) matching_vector);
 
 	  bfd_set_error (bfd_error_file_not_recognized);
 
@@ -210,7 +212,7 @@ bfd_check_format_matches (abfd, format, matching)
 
       abfd->xvec = *target;	/* Change BFD's target temporarily */
 
-      if (bfd_seek (abfd, (file_ptr)0, SEEK_SET) != 0)
+      if (bfd_seek (abfd, (file_ptr) 0, SEEK_SET) != 0)
 	return false;
 
       /* If _bfd_check_format neglects to set bfd_error, assume
@@ -235,7 +237,7 @@ bfd_check_format_matches (abfd, format, matching)
 	    }
 
 	  if (matching)
-	    matching_vector[match_count] = temp->name;
+	    matching_vector[match_count] = temp;
 
 	  match_count++;
 
@@ -258,7 +260,7 @@ bfd_check_format_matches (abfd, format, matching)
 	  if (ar_right_targ != bfd_default_vector[0])
 	    ar_right_targ = *target;
 	  if (matching)
-	    matching_vector[ar_match_index] = (*target)->name;
+	    matching_vector[ar_match_index] = *target;
 	  ar_match_index++;
 	}
       else if (err != bfd_error_wrong_format)
@@ -267,7 +269,7 @@ bfd_check_format_matches (abfd, format, matching)
 	  abfd->format = bfd_unknown;
 
 	  if (matching)
-	    free (matching_vector);
+	    free ((PTR) matching_vector);
 
 	  return false;
 	}
@@ -288,7 +290,27 @@ bfd_check_format_matches (abfd, format, matching)
 	    {
 	      memcpy (matching_vector,
 		      matching_vector + _bfd_target_vector_entries,
-		      sizeof (char *) * match_count);
+		      sizeof (*matching_vector) * match_count);
+	    }
+	}
+    }
+
+  if (match_count > 1 && bfd_associated_vector != NULL)
+    {
+      const bfd_target * const *assoc = bfd_associated_vector;
+
+      while ((right_targ = *assoc++) != NULL)
+	{
+	  int i = match_count;
+
+	  while (--i >= 0)
+	    if (matching_vector[i] == right_targ)
+	      break;
+
+	  if (i >= 0)
+	    {
+	      match_count = 1;
+	      break;
 	    }
 	}
     }
@@ -298,7 +320,7 @@ bfd_check_format_matches (abfd, format, matching)
       abfd->xvec = right_targ;		/* Change BFD's target permanently.  */
 
       if (matching)
-	free (matching_vector);
+	free ((PTR) matching_vector);
 
       return true;			/* File position has moved, BTW.  */
     }
@@ -311,7 +333,7 @@ bfd_check_format_matches (abfd, format, matching)
       bfd_set_error (bfd_error_file_not_recognized);
 
       if (matching)
-	free (matching_vector);
+	free ((PTR) matching_vector);
     }
   else
     {
@@ -319,8 +341,15 @@ bfd_check_format_matches (abfd, format, matching)
 
       if (matching)
 	{
-	  *matching = matching_vector;
+	  *matching = (char **) matching_vector;
 	  matching_vector[match_count] = NULL;
+	  /* Return target names.  This is a little nasty.  Maybe we
+	     should do another bfd_malloc?  */
+	  while (--match_count >= 0)
+	    {
+	      const char *name = matching_vector[match_count]->name;
+	      *(const char **) &matching_vector[match_count] = name;
+	    }
 	}
     }
 
@@ -354,7 +383,7 @@ bfd_set_format (abfd, format)
     }
 
   if (abfd->format != bfd_unknown)
-    return (abfd->format == format) ? true : false;
+    return (boolean) (abfd->format == format);
 
   /* Presume the answer is yes.  */
   abfd->format = format;
