@@ -1,5 +1,5 @@
 /* tc-i860.c -- Assembler for the Intel i860 architecture.
-   Copyright 1989, 1992, 1993, 1994, 1995, 1998, 1999, 2000, 2001
+   Copyright 1989, 1992, 1993, 1994, 1995, 1998, 1999, 2000, 2001, 2002
    Free Software Foundation, Inc.
 
    Brought back from the dead and completely reworked
@@ -1013,9 +1013,9 @@ print_insn (insn)
 
 
 #ifdef OBJ_ELF
-CONST char *md_shortopts = "VQ:";
+const char *md_shortopts = "VQ:";
 #else
-CONST char *md_shortopts = "";
+const char *md_shortopts = "";
 #endif
 
 #define OPTION_EB		(OPTION_MD_BASE + 0)
@@ -1228,15 +1228,15 @@ obtain_reloc_for_imm16 (fix, val)
 /* Attempt to simplify or eliminate a fixup. To indicate that a fixup
    has been eliminated, set fix->fx_done. If fix->fx_addsy is non-NULL,
    we will have to generate a reloc entry.  */
-int
-md_apply_fix3 (fix, valuep, seg)
-     fixS *fix;
-     valueT *valuep;
+
+void
+md_apply_fix3 (fix, valP, seg)
+     fixS * fix;
+     valueT * valP;
      segT seg ATTRIBUTE_UNUSED;
 {
-
   char *buf;
-  long val = (long) (*valuep);
+  long val = *valP;
   unsigned long insn;
   valueT fup;
 
@@ -1280,9 +1280,8 @@ md_apply_fix3 (fix, valuep, seg)
 	}
     }
   else if (fup & OP_IMM_U16)
-    {
-      abort ();
-    }
+    abort ();
+
   else if (fup & OP_IMM_SPLIT16)
     {
       fix->fx_r_type = obtain_reloc_for_imm16 (fix, &val);
@@ -1367,9 +1366,6 @@ md_apply_fix3 (fix, valuep, seg)
 	  fix->fx_done = 1;
 	}
     }
-
-  /* Return value ignored.  */
-  return 0;
 }
 
 /* Generate a machine dependent reloc from a fixup.  */
